@@ -61,7 +61,7 @@ MSGS = {
     'W1301': ("Unused key %r in format string dictionary",
               "unused-format-string-key",
               "Used when a format string that uses named conversion specifiers \
-              is used with a dictionary that conWtains keys not required by the \
+              is used with a dictionary that contains keys not required by the \
               format string."),
     'E1304': ("Missing key %r in format string dictionary",
               "missing-format-string-key",
