@@ -47,12 +47,9 @@ class BaseReporter(object):
 
     def __init__(self, output=None):
         self.linter = None
-        # self.include_ids = None # Deprecated
-        # self.symbols = None # Deprecated
         self.section = 0
         self.out = None
         self.out_encoding = None
-        self.encode = None
         self.set_output(output)
         # Build the path prefix to strip to get relative paths
         self.path_strip_prefix = os.getcwd() + os.sep
@@ -75,12 +72,11 @@ class BaseReporter(object):
     def set_output(self, output=None):
         """set output stream"""
         self.out = output or sys.stdout
-        # py3k streams handle their encoding :
-        if sys.version_info >= (3, 0):
-            self.encode = lambda x: x
-            return
 
-        def encode(string):
+    if six.PY3:
+        encode = lambda self, string: string
+    else:
+        def encode(self, string):
             if not isinstance(string, six.text_type):
                 return string
             encoding = (getattr(self.out, 'encoding', None) or
@@ -90,32 +86,46 @@ class BaseReporter(object):
             # source code line that can't be encoded with the current locale
             # settings
             return string.encode(encoding, 'replace')
-        self.encode = encode
 
     def writeln(self, string=''):
         """write a line in the output buffer"""
         print(self.encode(string), file=self.out)
 
-    def display_results(self, layout):
+    def display_reports(self, layout):
         """display results encapsulated in the layout tree"""
         self.section = 0
         if hasattr(layout, 'report_id'):
             layout.children[0].children[0].data += ' (%s)' % layout.report_id
         self._display(layout)
 
+    def display_results(self, layout):
+        warnings.warn("display_results is deprecated, use display_reports instead. "
+                      "The former will be removed in Pylint 2.0.",
+                      DeprecationWarning)
+        self.display_reports(layout)
+
     def _display(self, layout):
         """display the layout"""
         raise NotImplementedError()
 
+    def display_messages(self, layout):
+        """Hook for displaying the messages of the reporter
+
+        This will be called whenever the underlying messages
+        needs to be displayed. For some reporters, it probably
+        doesn't make sense to display messages as soon as they
+        are available, so some mechanism of storing them could be used.
+        This method can be implemented to display them after they've
+        been aggregated.
+        """
+
     # Event callbacks
 
     def on_set_current_module(self, module, filepath):
-        """starting analyzis of a module"""
-        pass
+        """Hook called when a module starts to be analysed."""
 
     def on_close(self, stats, previous_stats):
-        """global end of analyzis"""
-        pass
+        """Hook called when a module finished analyzing."""
 
 
 class CollectingReporter(BaseReporter):
